lcvtoolbox.core.schemas.cvat\_typed.CvatApiJobDetails
=====================================================

.. currentmodule:: lcvtoolbox.core.schemas.cvat_typed

.. autoclass:: CvatApiJobDetails
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CvatApiJobDetails.__init__
      ~CvatApiJobDetails.clear
      ~CvatApiJobDetails.copy
      ~CvatApiJobDetails.fromkeys
      ~CvatApiJobDetails.get
      ~CvatApiJobDetails.items
      ~CvatApiJobDetails.keys
      ~CvatApiJobDetails.pop
      ~CvatApiJobDetails.popitem
      ~CvatApiJobDetails.setdefault
      ~CvatApiJobDetails.update
      ~CvatApiJobDetails.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CvatApiJobDetails.id
      ~CvatApiJobDetails.task_id
      ~CvatApiJobDetails.project_id
      ~CvatApiJobDetails.assignee
      ~CvatApiJobDetails.guide_id
      ~CvatApiJobDetails.dimension
      ~CvatApiJobDetails.data_compressed_chunk_type
      ~CvatApiJobDetails.data_original_chunk_type
      ~CvatApiJobDetails.bug_tracker
      ~CvatApiJobDetails.mode
      ~CvatApiJobDetails.frame_count
      ~CvatApiJobDetails.start_frame
      ~CvatApiJobDetails.stop_frame
      ~CvatApiJobDetails.data_chunk_size
      ~CvatApiJobDetails.created_date
      ~CvatApiJobDetails.updated_date
      ~CvatApiJobDetails.issues
      ~CvatApiJobDetails.labels
      ~CvatApiJobDetails.type
      ~CvatApiJobDetails.organization
   
   